O que há neste pacote?
============
Pacote python da plug boleto, criação de boletos, consulta e endereço de impressão de boleto

Como utilizar esse pacote?
==========================
pip install lins-plugboleto

pip install requests


Como importar as funcionalidades do pacote?
===========================================
from lins_plugboleto import *
